/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view;

import junit.framework.TestCase;
import java.io.File;

/**
 * Unit test cases for DependencyRenderer.
 *
 * Testing of DependencyRenderer only handles the properties. The accuracy of the rendering algorithm
 * is tested in the FixedGridLayoutManager.
 *
 * @author TCSDeveloper
 */
public class NewDependencyRendererUnitTests extends TestCase {

    /**
     * The filename to persist to.
     */
    private String filename = "test_files/unittest.svg";

    /**
     * The shape factory to use.
     */
    private ShapeFactory factory = null;

    /**
     * The diagram renderer to use.
     */
    private DiagramRenderer dr = null;

    /**
     * A second diagram renderer to use.
     */
    private DiagramRenderer dr2 = null;
    
    /**
     * A Dependency instance for test.
     */
    private Dependency a = null;
    
    /**
     * A Dependency instance for test.
     */
    private Dependency b = null;
    
    /**
     * A Dependency instance for test.
     */
    private Dependency c = null;
    
    /**
     * A Dependency instance for test.
     */
    private Dependency d = null;
    
    /**
     * A Dependency instance for test.
     */
    private Dependency e = null;
    
    /**
     * A Dependency instance for test.
     */
    private Dependency f = null;
    
    /**
     * A Dependency instance for test.
     */
    private Dependency g = null;
    

    /**
     * The layout manager to use.
     */
    private LayoutManager manager = new FixedGridLayoutManager();

    /**
     * The dependency renderer instance to test.
     */
    private DependencyRenderer renderer = null;

    /**
     * Create instance of shape factory, diagram renderer and dependency renderer for each test.
     */
    protected void setUp() {
        factory = new ShapeFactory();
        dr = new SVGRenderer(new File(filename));
        dr2 = new SVGRenderer(new File(filename));
        renderer = new DependencyRenderer(factory);
        
        a = new Dependency("A");
        b = new Dependency("B");
        c = new Dependency("C");
        d = new Dependency("D");
        e = new Dependency("E");
        f = new Dependency("F");
        g = new Dependency("G");
        
        // build dependencies.           
        a.addDependant(b);
        a.addDependant(e);
        b.addDependant(c);
        b.addDependant(d);
        e.addDependant(f);
        
    }

    /**
     * Test renderAll(dependency) with null dependency.
     *
     * @throws RendererException to JUnit.
     */
    public void testRenderAll_NullDependency1() throws RendererException {
        try {
            renderer.renderAll(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) {
        }
    }
    
    /**
     * Test renderAll(dependency, renderTopLevel) with null dependency.
     *
     * @throws RendererException to JUnit.
     */
    public void testRenderAll_NullDependency2() throws RendererException {
        try {
            renderer.renderAll(null, true);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) {
        }
    }
    
	/**
     * Test renderAll(dependency).
     *
     * @throws RendererException to JUnit.
     */
    public void testRenderAll1() throws RendererException {
        renderer.addDiagramRenderer(dr);
        renderer.addDiagramRenderer(dr2);
        
        renderer.renderAll(a);
        
        File output = new File(filename);
        assertTrue("Output does not exist.", output.exists());
        output.delete();
    }
    
	/**
     * Test renderAll(dependency, renderTopLevel).
     *
     * @throws RendererException to JUnit.
     */
    public void testRenderAll2() throws RendererException {
        renderer.addDiagramRenderer(dr);
        renderer.addDiagramRenderer(dr2);
        
        renderer.renderAll(a, true);
        
        File output = new File(filename);
        assertTrue("Output does not exist.", output.exists());
        output.delete();
    }    
    
    /**
     * Test renderAll(dependency, renderTopLevel).
     *
     * @throws RendererException to JUnit.
     */
    public void testRenderAll3() throws RendererException {
        renderer.addDiagramRenderer(dr);
        renderer.addDiagramRenderer(dr2);
        
        renderer.renderAll(a, false);
        
        File output = new File(filename);
        assertTrue("Output does not exist.", output.exists());
        output.delete();
    }    
        
 }   